@@ -7,7 +7,8 @@
 
 from collections import defaultdict
 from configparser import ConfigParser, NoSectionError, NoOptionError
-from os.path import exists, join, dirname
+from os import makedirs
+from os.path import getmtime, exists, join, dirname
 
 from pylint import lint
 from pylint.config import PYLINTRC
@@ -18,6 +19,7 @@ from .pylint_util import ProgrammaticReporter
 from .util import get_rel_path, PyLintException, should_include_file
 
 HISTKEY = 'pylint/mtimes'
+PYLINT_CONFIG_CACHE_KEY = 'pylintrc'
 FILL_CHARS = 80
 MARKER = 'pylint'
 
@@ -117,6 +119,16 @@ class PylintPlugin:
         # collection methods and not pylint's internal mechanism
         if pylintrc_file and exists(pylintrc_file):
             self.pylintrc_file = pylintrc_file
+
+            # Check if pylint config has a different filename or date
+            # and invalidate the cache if it has changed.
+            pylint_mtime = getmtime(pylintrc_file)
+            cache_key = PYLINT_CONFIG_CACHE_KEY + pylintrc_file
+            cache_value = self.mtimes.get(cache_key)
+            if cache_value is None or cache_value < pylint_mtime:
+                self.mtimes = {}
+            self.mtimes[cache_key] = pylint_mtime
+
             if pylintrc_file.endswith(".toml"):
                 self._load_pyproject_toml(pylintrc_file)
             else:
@@ -142,9 +154,11 @@ class PylintPlugin:
             pass
 
         try:
-            self.pylint_ignore_patterns = self.pylint_config.get(
+            ignore_patterns = self.pylint_config.get(
                 'MASTER', 'ignore-patterns'
-            ).split(',')
+            )
+            if ignore_patterns:
+                self.pylint_ignore_patterns = ignore_patterns.split(',')
         except (NoSectionError, NoOptionError):
             pass
 
@@ -295,7 +309,7 @@ class PylintFile(pytest.File):
         """Create a PyLintItem for the File."""
         yield PyLintItem.from_parent(
             parent=self,
-            name='{}::PYLINT'.format(self.fspath)
+            name='PYLINT'
         )
 
 
@@ -355,6 +369,9 @@ class PyLintItem(pytest.Item):
             return reported_errors
 
         if pylint_output_file:
+            output_dir = dirname(pylint_output_file)
+            if output_dir:
+                makedirs(output_dir, exist_ok=True)
             with open(pylint_output_file, 'a') as _file:
                 reported_errors = _loop_errors(writer=_file.write)
         else:
